@@ -306,11 +306,11 @@ Net::CalDAVTalk - Module to talk CalDAV and give a JSON interface to the data
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -471,7 +471,8 @@ sub _fixColour {
   my $color = lc(shift || '');
 
   return $color if $ColourNames{$color};
-  return $DefaultCalendarColour unless $color =~ m/^(\#[a-f0-9]{3,8})$/;
+  return $DefaultCalendarColour unless $color =~ m/^\s*(\#[a-f0-9]{3,8})\s*$/;
+  $color = $1;
   return uc($color) if length($color) == 7;
 
   # Optional digit is for transparency (RGBA)
@@ -945,7 +946,7 @@ sub GetEvent {
   my $calendarId = $href;
   $calendarId =~ s{/[^/]*$}{};
 
-  my ($Events, $Errors) = $Self->GetEvents($calendarId, href => $Self->fullpath($href));
+  my ($Events, $Errors) = $Self->GetEvents($calendarId, %Args, href => $Self->fullpath($href));
 
   die "Errors @$Errors" if @$Errors;
   die "Multiple items returned for $href" if @$Events > 1;
@@ -2245,7 +2246,7 @@ sub _argsToVEvents {
       my %AttachProps;
       $AttachProps{FMTTYPE} = $Mime if defined $Mime;
       $AttachProps{SIZE} = $Size if defined $Size;
-      $AttachProps{NAME} = $FileName if defined $FileName;
+      $AttachProps{FILENAME} = $FileName if defined $FileName;
       $VEvent->add_property(attach => [ $Url, \%AttachProps ]);
     }
   }
@@ -2514,6 +2515,37 @@ sub vcalendarToEvents {
   return map { $map{$_} } sort keys %map;
 }
 
+=head2 $self->UpdateAddressSet($DisplayName, $EmailAddress)
+
+Set the address set and display name for the calendar user (if supported)
+
+=cut
+
+sub UpdateAddressSet {
+  my ($Self, $NewDisplayName, $NewAddressSet) = @_;
+
+  my ($DisplayName, $AddressSet) = $Self->GetProps(\$Self->{principal}, 'D:displayname', [ 'C:calendar-user-address-set', 'D:href' ]);
+
+  if (!$AddressSet || $AddressSet ne "mailto:" . $NewAddressSet ||
+      !$DisplayName || $DisplayName ne $NewDisplayName) {
+    $Self->Request(
+      'PROPPATCH',
+      "",
+      x('D:propertyupdate', $Self->NS(),
+        x('D:set',
+          x('D:prop',
+            x('D:displayname', $NewDisplayName),
+            x('C:calendar-user-address-set', "mailto:" . $NewAddressSet),
+          )
+        )
+      )
+    );
+    return 1;
+  }
+
+  return 0;
+}
+
 =head2 $self->GetICal($calendarId, $isFreeBusy)
 
 Given a calender, fetch all the events and generate an ical format file
@@ -2539,6 +2571,7 @@ sub GetICal {
     my $VCalendar = $Self->_argsToVCalendar($Events,
       method => 'PUBLISH',
       'x-wr-calname' => $Cal->{name},
+      'x-wr-timezone' => $Cal->{timezone},
       'x-apple-calendar-color' => $Cal->{color},
       # XXX - do we want to add our sync-token here or something?
     );
